Calculates the Mainstem San Joaquin juvenile out migration survival

surv_juv_outmigration_san_joaquin_flow_based(flow_cms)

https://reorienting-to-recovery.github.io/DSMflow/articles/EFF_SJ.html

Arguments

flow_cms

Variable representing upper San Joaquin River flow in cubic meters per second