Winter Run Chinook life cycle model used for Reorienting to Recovery's Structured Decision Making Process

winter_run_model(
  scenario = NULL,
  mode = c("seed", "simulate", "calibrate"),
  seeds = NULL,
  ..params = winterRunDSM::r_to_r_baseline_params,
  stochastic = FALSE,
  delta_surv_inflation = FALSE
)

IP-117068

Arguments

scenario

Model inputs, can be modified to test management actions

mode

The mode to run model in. Can be "seed", "simulate", "calibrate"

seeds

The default value is NULL runs the model in seeding mode, returning a 31 by 25 matrix with the first four years of seeded adults. This returned value can be fed into the model again as the value for the seeds argument

..params

Parameters for model and submodels. Defaults to winterRunDSM::params.

stochastic

TRUE FALSE value indicating if model should be run stochastically. Defaults to FALSE.

Examples

winter_run_seeds <- winterRunDSM::winter_run_model(mode = "seed")
winterRunDSM::winter_run_model(scenario = DSMscenario::scenarios$ONE,
                           mode = "simulate",
                           seeds = winter_run_seeds)
#> Error in case_when(scenario %in% c("elephant", "platypus", "tortoise",     "elephant_plus") ~ "balanced_scenarios", scenario == "baseline" ~     "baseline_scenarios", TRUE ~ "blended_scenarios"): could not find function "case_when"